@@ -1931,7 +1931,7 @@ remove_idle (EelCanvas *canvas)
 	if (canvas->idle_id == 0)
 		return;
 
-	gtk_idle_remove (canvas->idle_id);
+	g_source_remove (canvas->idle_id);
 	canvas->idle_id = 0;
 }
 
